/// <reference types="node" />
import { Market } from '@project-serum/serum';
import { Pool } from '../accounts';
import { ErrorCB, Fills, FillsExtended, FillsListenerCB, OrderbookListenerCB, ParsedOrderbook } from '../types';
import { CypherClient } from '../client/index';
import { Event } from '@project-serum/serum/lib/queue';
import { PublicKey } from '@solana/web3.js';
export declare class SpotMarketViewer {
    readonly client: CypherClient;
    readonly pool: Pool;
    private _bidsListener;
    private _asksListener;
    private _eventQueueListener;
    private _openOrdersAccountListener;
    private _lastSeqNum;
    constructor(client: CypherClient, pool: Pool);
    private get connection();
    get market(): Market;
    orderbookParser(data: Buffer, orderbookDepth?: number): ParsedOrderbook;
    eventQueueParser(data: Buffer): Event[];
    fillsParser(data: Buffer): FillsExtended;
    addBidsListener(callback: OrderbookListenerCB, errorCallback?: ErrorCB, orderbookDepth?: number): any;
    addAsksListener(callback: OrderbookListenerCB, errorCallback?: ErrorCB, orderbookDepth?: number): any;
    addEventQueueListener(callback: () => void, errorCallback: ErrorCB): any;
    addOpenOrdersAccountListener(openOrdersAccount: PublicKey, callback: (x: any) => void, errorCallback: ErrorCB): any;
    addFillsListener(callback: FillsListenerCB, errorCallback: ErrorCB): void;
    removeOpenOrdersAccountListener(): Promise<void>;
    removeBidsListener(): Promise<void>;
    removeAsksListener(): Promise<void>;
    removeEventQueueListener(): Promise<void>;
    calcMarketOrderPrice(size: number, side: 'buy' | 'sell', bids: ParsedOrderbook, asks: ParsedOrderbook, priceBonusFocus?: number): number;
    calcMarketOrderPriceForAvailableAmount(size: number, side: 'buy' | 'sell', bids: ParsedOrderbook, asks: ParsedOrderbook, priceBonusFocus?: number): number[];
    getTopAskPrice(asks: ParsedOrderbook): number;
    getlastPrice(fills: Fills): number;
    getMiddlePointPrice(bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    getContractsOnOrderbooks(bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    getOrderBook(): Promise<{
        bids: ParsedOrderbook;
        asks: ParsedOrderbook;
    }>;
    loadFills(): Promise<Fills>;
}
